# Author:         tomot
# Name:           DoorToolRight
# Description:    Create a simple Door
# Usage:          click 3 points, into an EXISTING OPENING, creates a Right Hand or Right Hand Reverse Door
# Date:           2008 
# Type:           Tool
# Revised:        I'm planning an replacing each of the globals with an alpha numeric random sequence.
#                 Such as $tp3xcH. This will avoid global naming conflicts with other rubies. 
#                 But most importantly it will retain the values the user enters into the various dialog box entries.
#--------------------------------------------------------------------------------------------------------------------
require 'sketchup.rb'

class DoorToolRight
def initialize
    $ip = Sketchup::InputPoint.new
    $ip1 = Sketchup::InputPoint.new
    reset

    # sets the default Door settings
    $dwthick = 6.0. inch if not $dwthick            # door frame/wall thickness
    $rdfthick = 0.0. inch if not $rdfthick          # door frame thickness
    $rdthick = 1.5. inch if not $rdthick            # door thickness
    $rdsthick = 6.0. inch if not $rdsthick          # door style width
    $rdtthick = 6.0. inch if not $rdtthick          # door top rail width
    $rdbthick = 12.0. inch if not $rdbthick         # door btm rail width
    $rdlatchht = 40.0. inch if not $rdlatchht       # door latch height
    $rdoorswing = "Right Hand" if not $rdoorswing   # right hand or right hand reverse
    $rdoorstyle = "Slab" if not $rdoorstyle         # slab,panel,panel&glass,glass
    $rpanicrail = "NO" if not $lpanicrail           # panic rail No or Yes
    $rhardware = "YES" if not $rhardware            # hardware No or Yes
    
    # Set the layer names
    $doorlayer= "Doors" if not $doorlayer           #layer for door
    $swinglayer= "DoorSwing" if not $swinglayer     #layer for doorswing
         
    # Dialog box
    rswing = ["Right Hand", "Right Hand Rev"]
    rstyle = ["Slab", "Panel", "Panel Open", "Panel & Glass", "Glass"]
    rpanic = ["YES","NO"]
    rhware = ["YES","NO"]
    enums = ["", rswing.join("|"), rstyle.join("|"), "", "", "", "", "", rpanic.join("|"), rhware.join("|")]
    prompts = ["Wall Thickness", "Door Swing", "Door Style", "Door Layer", "Door Thickness", "Door Style Width ", "Door Top Rail Width", "Door Btm Rail Width ", "Panic Rail", "Hareware"]
    values = [$dwthick, $rdoorswing, $rdoorstyle, $doorlayer, $rdthick, $rdsthick, $rdtthick, $rdbthick, $rpanicrail, $rhardware]
    results = inputbox prompts, values, enums, "Right Hand Door parameters"
    
    return nil if not results
    $dwthick, $rdoorswing, $rdoorstyle, $doorlayer, $rdthick, $rdsthick, $rdtthick, $rdbthick, $rpanicrail, $rhardware = results
    
    if ($rdsthick < 3)
       UI.messagebox( "Door Style Width less than 3 is not allowed ")
    return nil
    end
    
    if ($rdsthick > 12)
       UI.messagebox( "Door Style Width more than 12 is not allowed ")
    return nil
    end
    
    if ($rdbthick < 3)
       UI.messagebox( "Door Btm Rail Width less than 3 is not allowed ")
    return nil
    end
    
    if ($rdbthick > 12)
       UI.messagebox( "Door Btm Rail Width more than 12 is not allowed ")
    return nil
    end
    
    if ($rdtthick < 3)
       UI.messagebox( "Door Top Rail Width less than 3 is not allowed ")
    return nil
    end
    
    if ($rdtthick > 12)
       UI.messagebox( "Door Top Rail Width more than 12 is not allowed ")
    return nil
    end
    
end #end initialize
#---------------------------------------------------------------------------
def reset
    $pts = []
    $state = 0
    $ip1.clear
    $drawn = false
    Sketchup::set_status_text "", SB_VCB_LABEL
    Sketchup::set_status_text "", SB_VCB_VALUE
    Sketchup::set_status_text "Click Top Right for Right Hand Door"
    $shift_down_time = Time.now
end

def activate
    self.reset
end

def deactivate(view)
    view.invalidate if $drawn
end

def set_current_point(x, y, view)
    if( !$ip.pick(view, x, y, $ip1) )
        return false
    end
    need_draw = true
    
    # Set the tooltip that will be displayed
    view.tooltip = $ip.tooltip
        
    # Compute points
    case $state
    when 0
        $pts[0] = $ip.position
        $pts[4] = $pts[0]
        need_draw = $ip.display? || $drawn
    when 1
        $pts[1] = $ip.position
        $length = $pts[0].distance $pts[1]
        Sketchup::set_status_text $length.to_s, SB_VCB_VALUE
    when 2
        pt1 = $ip.position
        pt2 = pt1.project_to_line $pts
        vec = pt1 - pt2

        $pt1 = $ip.position
        $pt2 = pt1.project_to_line $pts
        $vec = $pt1 - $pt2


        $width = vec.length
        if( $width > 0 )
            # test for a square
            square_point = pt2.offset(vec, $length)
            if( view.pick_helper.test_point(square_point, x, y) )
                $width = $length
                $pts[2] = $pts[1].offset(vec, $width)
                $pts[3] = $pts[0].offset(vec, $width)
                view.tooltip = "Square"
            else
                $pts[2] = $pts[1].offset(vec)
                $pts[3] = $pts[0].offset(vec)
            end
        else
            $pts[2] = $pts[1]
            $pts[3] = $pts[0]
        end
        Sketchup::set_status_text $width.to_s, SB_VCB_VALUE
    end

    view.invalidate if need_draw
end

def onMouseMove(flags, x, y, view)
    self.set_current_point(x, y, view)
end

#--------------------------------------------------------------------------
def create_rectangle
#--------------------------------------------------------------------------
    
    model=Sketchup.active_model
    #------Set and activate the Doors layer
    layers = model.layers
    layers.add ($doorlayer)
    activelayer = model.active_layer=layers[$doorlayer]
    layer=model.active_layer
    
    model.start_operation "Create Door"
    entities=model.active_entities
    
    # creates a new point from p1 in the direction of p2-p3 with length d
    # params are Point3d, 2 vertices, a length, returns a Point3d
    def translate(p1, p2, p3, d)
        v = p3 - p2
        v.length = d
        trans=Geom::Transformation.translation(v)
        return p1.transform(trans)
    end 
    
    #---Rotation definition for around z axis:
    def translate_rotate_z(p1, p2, d, angle)
        v = p2 - p1
        v.length = d
        translate = Geom::Transformation.translation(v)
        p_temp = p1.transform(translate)
        rotate = Geom::Transformation.rotation( p1, Geom::Vector3d.new(0,0,1),angle)
        result = p_temp.transform(rotate)
        return result
    end
    
    pi = 3.141592653589793  # 180 degree angle = pi radians
    vecz = Geom::Vector3d.new(0, 0, 1)
    vecy = Geom::Vector3d.new(0, 1, 0)     
    vecx = Geom::Vector3d.new(1, 0, 0) 
   
	#------create a new set of points from the original 3 point pick
    $pt0=Geom::Point3d.new($pts[0][0], $pts[0][1], $pts[0][2])
    $pt1=Geom::Point3d.new($pts[1][0], $pts[1][1], $pts[1][2])
    $pt2=Geom::Point3d.new($pts[2][0], $pts[2][1], $pts[2][2])
    $pt3=Geom::Point3d.new($pts[3][0], $pts[3][1], $pts[3][2])
    
   
    $pt0j=translate($pt0, $pt0, $pt3, $rdfthick)
    $pt1j=translate($pt1, $pt1, $pt2, $rdfthick)
    $pt0jj=translate($pt0j, $pt0j, $pt1j, $rdfthick)
    $pt3jj=translate($pt3, $pt3, $pt2, $rdfthick)
    $pt1jj=translate($pt1j, $pt1j, $pt0j, $rdfthick)
    $pt2jj=translate($pt2, $pt2, $pt3, $rdfthick)
    $pt0jja=translate($pt0jj, $pt0jj, $pt1j, $rdsthick) 
    $pt3jja=translate($pt3jj, $pt3jj, $pt2, $rdsthick) 
    $pt1jja=translate($pt1jj, $pt1jj, $pt0j, $rdsthick) 
    $pt2jja=translate($pt2jj, $pt2jj, $pt3, $rdsthick) 
    $pt3jjb=translate($pt3jja, $pt3jja, $pt0jja, $rdbthick) 
    $pt2jjb=translate($pt2jja, $pt2jja, $pt1jja, $rdbthick) 
    $pt0jjb=translate($pt0jja, $pt0jja, $pt3jja, $rdtthick) 
    $pt1jjb=translate($pt1jja, $pt1jja, $pt2jja, $rdtthick) 
    #------width of door
    $dwidth=$pt0jj.distance $pt1jj
    #-----width of door/2
    $pt4=translate($pt0, $pt0, $pt1, $dwidth/2)
    $pt5=translate($pt3, $pt3, $pt2, $dwidth/2) 
    #-----Escution Plate
    $pt3jjh=translate($pt3jj, $pt3jj, $pt0jj, $rdlatchht+$rdsthick/2) 
    $pt3jjc=translate($pt3jja, $pt3jja, $pt0jja, $rdlatchht+$rdsthick/2) 
    $pt3jjhl=translate($pt3jj, $pt3jj, $pt0jj, $rdlatchht-$rdsthick/2) 
    $pt3jjcl=translate($pt3jja, $pt3jja, $pt0jja, $rdlatchht-$rdsthick/2) 
    #-----Do Door Knob 
    $pt3jjhc=translate($pt3jjh, $pt3jjh, $pt3jjc, $rdsthick/2)
    $pt3jjhlc=translate($pt3jjhl, $pt3jjhl, $pt3jjcl, $rdsthick/2)
    #-----Panic Bar   
    $pt2jjc=translate($pt2jja, $pt2jja, $pt1jja, $rdlatchht+$rdsthick/2)
    $pt2jjcl=translate($pt2jja, $pt2jja, $pt1jja, $rdlatchht-$rdsthick/2)
    
#---------------------------------------------------------------
# Do Right Hand Door
#---------------------------------------------------------------
if( $rdoorswing == "Right Hand" ) 

    if( $rhardware != "NO" )           
        #-----Do Escution Plate
        group=entities.add_group
        entities=group.entities
        base=entities.add_face($pt3jjcl, $pt3jjc, $pt3jjh, $pt3jjhl)
        base.pushpull $rdthick+ $rdthick/8
        #-----Do Escution Plate other side
        base=entities.add_face($pt3jjcl, $pt3jjc, $pt3jjh, $pt3jjhl)
        base.pushpull $rdthick/8
        #-----Do Door Knob 
        $ptknob=translate($pt3jja, $pt3jja, $pt3jjhlc, $rdlatchht)
        $Vec0 = $pt1 - $pt0
        $Vec1 = $pt0 - $pt1
        $Vec2 = $pt0 - $pt3
        # The cross product of two vectors produces a third vector which 
        #is perpendicular to the plane in which the first two lie.
        $Vec3 = $Vec1 * $Vec2
        group=entities.add_group
        entities=group.entities
        circle = entities.add_circle($ptknob, $Vec3, 3/2, 24)
        hware = entities.add_face(circle)
        hware.pushpull -$rdthick*2
        hware.pushpull $rdthick
    end #if    
    
    if( $rpanicrail != "NO" ) 
        #------Panic Rail 
        group=entities.add_group
        rail=group.entities.add_face($pt3jjc, $pt2jjc, $pt2jjcl, $pt3jjcl)
        rail.pushpull -$rdthick
    end #if  
    
    if( $rdoorstyle == "Slab" )     
        #------Do Slab Door 
        group=entities.add_group
        entities=group.entities
        base=entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        base.pushpull -$rdthick
    end  #if  
    
    if( $rdoorstyle == "Panel" )      
        #------Do Slab Door 
        group=entities.add_group
        entities=group.entities
        base=entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        base.pushpull -$rdthick
        #------Cut Panel Opening
        base=entities.add_face($pt0jjb, $pt1jjb, $pt2jjb, $pt3jjb)
        base.pushpull -$rdthick
        #------Install Panel
        group=entities.add_group
        entities=group.entities
        base=entities.add_face($pt0jjb, $pt1jjb, $pt2jjb, $pt3jjb)
        base.pushpull $rdthick/3
    
        normal = base.normal
        normal.length = $rdthick*2/3
        tr = Geom::Transformation.translation(normal)
        group.transform! tr
    end  #if  

    if( $rdoorstyle == "Panel Open" )      
        #------Do Slab Door 
        group=entities.add_group
        entities=group.entities
        base=entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        base.pushpull -$rdthick
        #------Cut Panel Opening
        base=entities.add_face($pt0jjb, $pt1jjb, $pt2jjb, $pt3jjb)
        base.pushpull -$rdthick
    end #if    

    if( $rdoorstyle == "Panel & Glass" ) 
        #------Do Slab Door 
        group=entities.add_group
        entities=group.entities
        base=entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        base.pushpull -$rdthick
        #------Cut Panel Opening
        base=entities.add_face($pt0jjb, $pt1jjb, $pt2jjb, $pt3jjb)
        base.pushpull -$rdthick
        #------Install Glazing Panel
        group=entities.add_group
        entities=group.entities
        glaz=entities.add_face($pt2jjb, $pt3jjb, $pt0jjb, $pt1jjb)
        glaz.material=Sketchup::Color.new(163,204,204) #use RGB Color numbers
        glaz.material.alpha = 0.6 

        normal = base.normal
        normal.length = $rdthick/2
        tr = Geom::Transformation.translation(normal.reverse)
        group.transform! tr
    end #if   

    if( $rdoorstyle == "Glass" )     
        #------Do Slab Door 
        group=entities.add_group
        entities=group.entities
        glass=entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        glass.material=Sketchup::Color.new(163,204,204) #use RGB Color numbers
        glass.material.alpha = 0.6 
        glass.pushpull -$rdthick/3
        
        normal = glass.normal
        normal.length = -$rdthick/4
        tr = Geom::Transformation.translation(normal)
        group.transform! tr
    end #if   

    #------Set and activate the Door Swing layer
    layers = model.layers
    layers.add ($swinglayer)
    activelayer = model.active_layer=layers[$swinglayer]
    layer=model.active_layer

    #------ Draw Right Hand Door arc  OK!
    $pt6=translate_rotate_z($pt2jj, $pt3jj, -$dwidth, pi/2)
    model.entities.add_line($pt2jj, $pt6) #90 degree line
    model.entities.add_line($pt3jj, $pt6) #diagonal line
    #model.entities.add_arc($pt2jj, vecx, vecz, $dwidth, -pi/2, 0, 24)
    
end  #end if Right Hand Door 
#---------------------------------------------------------------
# Do Right Hand Reverse Door
#---------------------------------------------------------------
if( $rdoorswing == "Right Hand Rev" ) 
    
    if( $rpanicrail != "NO" ) 
        #------Panic Rail 
        group=entities.add_group
        rail=group.entities.add_face($pt3jjc, $pt2jjc, $pt2jjcl, $pt3jjcl)
        rail.pushpull -$rdthick
        
        normal = rail.normal
        normal.length = -$dwthick+$rdthick
        tr = Geom::Transformation.translation(normal)
        group.transform! tr
    end #if  

    if( $rdoorstyle == "Slab" )     
        #------Do Slab Door 
        group=entities.add_group
        slab=group.entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        slab.pushpull $rdthick
        
        normal = slab.normal
        normal.length = -$dwthick 
        tr = Geom::Transformation.translation(normal.reverse)
        group.transform! tr
    end  #if  

    if( $rdoorstyle == "Panel" )      
        #------Do Slab Door 
        group=entities.add_group
        panel=group.entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        panel.pushpull $rdthick
        
        normal = panel.normal
        normal.length = $dwthick 
        tr = Geom::Transformation.translation(normal)
        group.transform! tr
        
        #------Cut Panel Opening
        panel=group.entities.add_face($pt0jjb, $pt1jjb, $pt2jjb, $pt3jjb)
        panel.pushpull -$rdthick
        #------Install Panel
        group=entities.add_group
        panel=group.entities.add_face($pt0jjb, $pt1jjb, $pt2jjb, $pt3jjb)
        panel.pushpull $rdthick/3
    
        normal = panel.normal
        normal.length = $dwthick-$rdthick/3
        tr = Geom::Transformation.translation(normal)
        group.transform! tr
    end  #if   

    if( $rdoorstyle == "Panel Open" )      
        #------Do Slab Door 
        group=entities.add_group
        open=group.entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        open.pushpull $rdthick
        
        normal = open.normal
        normal.length = $dwthick 
        tr = Geom::Transformation.translation(normal)
        group.transform! tr
        
        #------Cut Panel Opening
        open=group.entities.add_face($pt0jjb, $pt1jjb, $pt2jjb, $pt3jjb)
        open.pushpull -$rdthick
    end #if    

    if( $rdoorstyle == "Panel & Glass" ) 
        #------Do Slab Door 
        group=entities.add_group
        pangl=group.entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        pangl.pushpull $rdthick
        
        normal = pangl.normal
        normal.length = $dwthick 
        tr = Geom::Transformation.translation(normal)
        group.transform! tr
        
        #------Cut Panel Opening
        pangl=group.entities.add_face($pt0jjb, $pt1jjb, $pt2jjb, $pt3jjb)
        pangl.pushpull -$rdthick
        
        #------Install Glazing Panel
        group=entities.add_group
        glaz=group.entities.add_face($pt2jjb, $pt3jjb, $pt0jjb, $pt1jjb)
        glaz.material=Sketchup::Color.new(163,204,204) #use RGB Color numbers
        glaz.material.alpha = 0.6 

        normal = glaz.normal
        normal.length = $dwthick-$rdthick/2
        tr = Geom::Transformation.translation(normal.reverse)
        group.transform! tr
    end #if   

    if( $rdoorstyle == "Glass" )     
        #------Do Slab Door 
        group=entities.add_group
        glass=group.entities.add_face($pt0jj, $pt1jj, $pt2jj, $pt3jj)
        glass.material=Sketchup::Color.new(163,204,204) #use RGB Color numbers
        glass.material.alpha = 0.6 
        glass.pushpull $rdthick/3
        
        normal = glass.normal
        normal.length = $dwthick-$rdthick/4
        tr = Geom::Transformation.translation(normal)
        group.transform! tr
    end #if   
    
    if( $rhardware != "NO" )  
        #-----Do Escution Plate
        group=entities.add_group
        entities=group.entities
        base=entities.add_face($pt3jjcl, $pt3jjc, $pt3jjh, $pt3jjhl)
        base.pushpull $rdthick/8
        #-----Do Escution Plate other side
        base=entities.add_face($pt3jjcl, $pt3jjc, $pt3jjh, $pt3jjhl)
        base.pushpull $rdthick+ $rdthick/8
    
        normal = base.normal
        normal.length = $dwthick 
        tr = Geom::Transformation.translation(normal.reverse)
        group.transform! tr
        
        #-----Do Door Knob 
        $ptknob=translate($pt3jja, $pt3jja, $pt3jjhlc, $rdlatchht)
        $Vec0 = $pt1 - $pt0
        $Vec1 = $pt0 - $pt1
        $Vec2 = $pt0 - $pt3
        # The cross product of two vectors produces a third vector which 
        #is perpendicular to the plane in which the first two lie.
        $Vec3 = $Vec1 * $Vec2
        group=entities.add_group
        entities=group.entities
        circle = entities.add_circle($ptknob, $Vec3, 3/2, 24)
        hware = entities.add_face(circle)
        hware.pushpull $rdthick*2
        hware.pushpull $rdthick
    end #if   

    #------Set and activate the Door Swing layer
    layers = model.layers
    layers.add ($swinglayer)
    activelayer = model.active_layer=layers[$swinglayer]
    layer=model.active_layer
    
    #------Draw Right Hand Reverse Door arc
    $pt8=translate_rotate_z($pt3jj, $pt2jj, -$dwthick, pi/2)
    $pt9=translate_rotate_z($pt2jj, $pt3jj, $dwthick, pi/2)
    $pt10=translate_rotate_z($pt2jj, $pt3jj, $dwthick+$dwidth, pi/2)
    model.entities.add_line($pt9, $pt10) #90 degree line
    model.entities.add_line($pt8, $pt10) #diagonal line
    #model.entities.add_arc($pt9, vecx, vecz, $dwidth,  0, pi/2, 24)

end  #end if Right Hand Reverse Door
#------------------------------------------------------------------
    
    #------Reset layer back to default layer [0]
	layers = model.layers
    activelayer = model.active_layer=layers[0]
	layer=model.active_layer
    
     model.commit_operation
end
#----------------------------------------------------------------------
def increment_state
    $state += 1
    case $state
    when 1
        $ip1.copy! $ip
        Sketchup::set_status_text "Click opposite Top Corner for 2nd point"
        Sketchup::set_status_text "", SB_VCB_LABEL
        Sketchup::set_status_text "", SB_VCB_VALUE
    when 2
        $ip1.clear
        Sketchup::set_status_text "Click btm. Corner for 3rd point"
        Sketchup::set_status_text "", SB_VCB_LABEL
        Sketchup::set_status_text "", SB_VCB_VALUE
    when 3
        self.create_rectangle
    end
end

def onLButtonDown(flags, x, y, view)
    self.set_current_point(x, y, view)
    self.increment_state
    view.lock_inference
end

def onCancel(flag, view)
    view.invalidate if $drawn
    self.reset
end

# This is called when the user types a value into the VCB
def onUserText(text, view)
    # The user may type in something that we can't parse as a length
    # so we set up some exception handling to trap that
    begin
        value = text.to_l
    rescue
        # Error parsing the text
        UI.beep
        value = nil
        Sketchup::set_status_text "", SB_VCB_VALUE
    end
    return if !value
    
    case $state
    when 1
        # update the width
        vec = $pts[1] - $pts[0]
        if( vec.length > 0.0 )
            vec.length = value
            $pts[1] = $pts[0].offset(vec)
            view.invalidate
            self.increment_state
        end
    when 2
        # update the height
        vec = $pts[3] - $pts[0]
        if( vec.length > 0.0 )
            vec.length = value
            $pts[2] = $pts[1].offset(vec)
            $pts[3] = $pts[0].offset(vec)
            self.increment_state
        end
    end
end

def getExtents
    bb = Geom::BoundingBox.new
    case $state
    when 0
        # We are getting the first point
        if( $ip.valid? && $ip.display? )
            bb.add $ip.position
        end
    when 1
        bb.add $pts[0]
        bb.add $pts[1]
    when 2
        bb.add $pts
    end
    bb
end

def draw(view)
    $drawn = false
    
    # Show the current input point
    if( $ip.valid? && $ip.display? )
        $ip.draw(view)
        $drawn = true
    end

    # show the rectangle
    if( $state == 1 )
        # just draw a line from the start to the end point
        view.set_color_from_line($ip1, $ip)
        inference_locked = view.inference_locked?
        view.line_width = 3 if inference_locked
        view.draw(GL_LINE_STRIP, $pts[0], $pts[1])
        view.line_width = 1 if inference_locked
        $drawn = true
    elsif( $state > 1 )
        # draw the curve
        view.drawing_color = "black"
        view.draw(GL_LINE_STRIP, $pts)
        $drawn = true
    end
end

def onKeyDown(key, rpt, flags, view)
    if( key == CONSTRAIN_MODIFIER_KEY && rpt == 1 )
        $shift_down_time = Time.now
        
        # if we already have an inference lock, then unlock it
        if( view.inference_locked? )
            view.lock_inference
        elsif( $state == 0 )
            view.lock_inference $ip
        elsif( $state == 1 )
            view.lock_inference $ip, $ip1
        end
    end
end

def onKeyUp(key, rpt, flags, view)
    if( key == CONSTRAIN_MODIFIER_KEY &&
        view.inference_locked? &&
        (Time.now - $shift_down_time) > 0.5 )
        view.lock_inference
    end
end

  
end # of class DoorToolRight
#=============================================================================
def DoorTool
    Sketchup.active_model.select_tool DoorToolRight.new
end

if( not file_loaded?("DoorToolRight.rb") )
    UI.menu("Plugins").add_item("DoorTool Right") { Sketchup.active_model.select_tool DoorToolRight.new }
end
#-----------------------------------------------------------------------------
file_loaded("DoorToolRight.rb") # load"DoorToolRight.rb"
